.. This work is licensed under the Creative Commons Attribution 4.0
   International License. To view a copy of this license, visit
   http://creativecommons.org/licenses/by/4.0/.

================
testcloud API
================


instance
========

.. automodule:: testcloud.instance
   :members:

image
=====

.. automodule:: testcloud.image
   :members:

util
====

.. automodule:: testcloud.util
   :members:

cli
====

.. automodule:: testcloud.cli
   :members:
